@@ -4,6 +4,7 @@ import (
 	"os"
 	"os/exec"
 	"path/filepath"
+	"regexp"
 	"strings"
 
 	"github.com/infracost/infracost/internal/schema"
@@ -57,6 +58,8 @@ func DetectProjectMetadata(path string) *schema.ProjectMetadata {
 		vcsSubPath = gitSubPath(path)
 	}
 
+	vcsRepoURL = stripVCSRepoPassword(vcsRepoURL)
+
 	return &schema.ProjectMetadata{
 		Path:               path,
 		VCSRepoURL:         vcsRepoURL,
@@ -121,3 +124,8 @@ func gitToplevel(path string) (string, error) {
 	}
 	return strings.Split(string(out), "\n")[0], nil
 }
+
+func stripVCSRepoPassword(repoURL string) string {
+	r := regexp.MustCompile(`.*:([^@]*)@`)
+	return r.ReplaceAllString(repoURL, "")
+}
