@@ -136,7 +136,9 @@ func baseVersion(v string) string {
 }
 
 func ciScript() string {
-	if IsEnvPresent("INFRACOST_CI_DIFF") {
+	if IsEnvPresent("INFRACOST_GITHUB_ACTION") {
+		return "infracost-github-action"
+	} else if IsEnvPresent("INFRACOST_CI_DIFF") {
 		return "ci-diff"
 	} else if IsEnvPresent("INFRACOST_CI_ATLANTIS_DIFF") {
 		return "ci-atlantis-diff"
@@ -166,6 +168,8 @@ func ciPlatform() string {
 		return "env0"
 	} else if IsEnvPresent("SCALR_RUN_ID") {
 		return "scalr"
+	} else if IsEnvPresent("CF_BUILD_ID") {
+		return "codefresh"
 	} else {
 		envKeys := os.Environ()
 		sort.Strings(envKeys)
