@@ -22,7 +22,7 @@ var ResourceRegistry []*schema.RegistryItem = []*schema.RegistryItem{
 	GetConfigurationRecorderItem(),
 	GetConfigOrganizationCustomRuleItem(),
 	GetConfigOrganizationManagedRuleItem(),
-	GetDataTransferRegistryItem(),
+	getDataTransferRegistryItem(),
 	GetDBInstanceRegistryItem(),
 	GetDMSRegistryItem(),
 	GetDocDBClusterInstanceRegistryItem(),
@@ -280,6 +280,9 @@ var FreeResources = []string{
 	"aws_dms_replication_task",
 	"aws_docdb_cluster_parameter_group",
 	"aws_docdb_subnet_group",
+	"aws_dynamodb_table_item",
+	"aws_ebs_encryption_by_default",
+	"aws_ebs_default_kms_key",
 	"aws_ecs_cluster",
 	"aws_ecs_task_definition",
 	"aws_eip_association",
@@ -356,7 +359,6 @@ var FreeResources = []string{
 	"aws_default_subnet",
 	"aws_default_vpc",
 	"aws_default_vpc_dhcp_options",
-	"aws_ebs_encryption_by_default",
 	"aws_ec2_client_vpn_authorization_rule",
 	"aws_ec2_client_vpn_route",
 	"aws_ec2_tag",
