@@ -5,6 +5,7 @@ import (
 	"encoding/json"
 	"os"
 	"path/filepath"
+	"sort"
 
 	"github.com/infracost/infracost/internal/config"
 	"github.com/infracost/infracost/internal/schema"
@@ -27,6 +28,11 @@ type TerragruntInfo struct {
 	WorkingDir string
 }
 
+type terragruntProjectDirs struct {
+	ConfigDir  string
+	WorkingDir string
+}
+
 func NewTerragruntProvider(ctx *config.ProjectContext) schema.Provider {
 	dirProvider := NewDirProvider(ctx).(*DirProvider)
 
@@ -61,7 +67,7 @@ func (p *TerragruntProvider) LoadResources(usage map[string]*schema.UsageData) (
 	// We want to run Terragrunt commands from the config dirs
 	// Terragrunt internally runs Terraform in the working dirs, so we need to be aware of these
 	// so we can handle reading and cleaning up the generated plan files.
-	configDirs, workingDirs, err := p.getProjectDirs()
+	projectDirs, err := p.getProjectDirs()
 
 	if err != nil {
 		return []*schema.Project{}, err
@@ -70,18 +76,18 @@ func (p *TerragruntProvider) LoadResources(usage map[string]*schema.UsageData) (
 	var outs [][]byte
 
 	if p.UseState {
-		outs, err = p.generateStateJSONs(configDirs)
+		outs, err = p.generateStateJSONs(projectDirs)
 	} else {
-		outs, err = p.generatePlanJSONs(configDirs, workingDirs)
+		outs, err = p.generatePlanJSONs(projectDirs)
 	}
 	if err != nil {
 		return []*schema.Project{}, err
 	}
 
-	projects := make([]*schema.Project, 0, len(configDirs))
+	projects := make([]*schema.Project, 0, len(projectDirs))
 
-	for i, path := range configDirs {
-		metadata := config.DetectProjectMetadata(path)
+	for i, projectDir := range projectDirs {
+		metadata := config.DetectProjectMetadata(projectDir.ConfigDir)
 		metadata.Type = p.Type()
 		p.AddMetadata(metadata)
 		name := schema.GenerateProjectName(metadata, p.ctx.RunContext.Config.EnableDashboard)
@@ -106,7 +112,7 @@ func (p *TerragruntProvider) LoadResources(usage map[string]*schema.UsageData) (
 	return projects, nil
 }
 
-func (p *TerragruntProvider) getProjectDirs() ([]string, []string, error) {
+func (p *TerragruntProvider) getProjectDirs() ([]terragruntProjectDirs, error) {
 	spinner := ui.NewSpinner("Running terragrunt run-all terragrunt-info", p.spinnerOpts)
 
 	opts := &CmdOptions{
@@ -118,7 +124,7 @@ func (p *TerragruntProvider) getProjectDirs() ([]string, []string, error) {
 		spinner.Fail()
 		p.printTerraformErr(err)
 
-		return []string{}, []string{}, err
+		return []terragruntProjectDirs{}, err
 	}
 
 	jsons := bytes.SplitAfter(out, []byte{'}', '\n'})
@@ -126,42 +132,48 @@ func (p *TerragruntProvider) getProjectDirs() ([]string, []string, error) {
 		jsons = jsons[:len(jsons)-1]
 	}
 
-	configDirs := make([]string, 0, len(jsons))
-	workingDirs := make([]string, 0, len(jsons))
+	dirs := make([]terragruntProjectDirs, 0, len(jsons))
 
 	for _, j := range jsons {
 		var info TerragruntInfo
 		err = json.Unmarshal(j, &info)
 		if err != nil {
 			spinner.Fail()
-			return configDirs, workingDirs, err
+			return dirs, err
 		}
 
-		configDirs = append(configDirs, filepath.Dir(info.ConfigPath))
-		workingDirs = append(workingDirs, info.WorkingDir)
+		dirs = append(dirs, terragruntProjectDirs{
+			ConfigDir:  filepath.Dir(info.ConfigPath),
+			WorkingDir: info.WorkingDir,
+		})
 	}
 
+	// Sort the dirs so they are consistent in the output
+	sort.Slice(dirs, func(i, j int) bool {
+		return dirs[i].ConfigDir < dirs[j].ConfigDir
+	})
+
 	spinner.Success()
 
-	return configDirs, workingDirs, nil
+	return dirs, nil
 }
 
-func (p *TerragruntProvider) generateStateJSONs(configDirs []string) ([][]byte, error) {
+func (p *TerragruntProvider) generateStateJSONs(projectDirs []terragruntProjectDirs) ([][]byte, error) {
 	err := p.checks()
 	if err != nil {
 		return [][]byte{}, err
 	}
 
-	outs := make([][]byte, 0, len(configDirs))
+	outs := make([][]byte, 0, len(projectDirs))
 
 	spinnerMsg := "Running terragrunt show"
-	if len(configDirs) > 1 {
+	if len(projectDirs) > 1 {
 		spinnerMsg += " for each project"
 	}
 	spinner := ui.NewSpinner(spinnerMsg, p.spinnerOpts)
 
-	for _, path := range configDirs {
-		opts, err := p.buildCommandOpts(path)
+	for _, projectDir := range projectDirs {
+		opts, err := p.buildCommandOpts(projectDir.ConfigDir)
 		if err != nil {
 			return [][]byte{}, err
 		}
@@ -179,7 +191,7 @@ func (p *TerragruntProvider) generateStateJSONs(configDirs []string) ([][]byte,
 	return outs, nil
 }
 
-func (p *DirProvider) generatePlanJSONs(configDirs []string, workingDirs []string) ([][]byte, error) {
+func (p *DirProvider) generatePlanJSONs(projectDirs []terragruntProjectDirs) ([][]byte, error) {
 	err := p.checks()
 	if err != nil {
 		return [][]byte{}, err
@@ -196,7 +208,7 @@ func (p *DirProvider) generatePlanJSONs(configDirs []string, workingDirs []strin
 	spinner := ui.NewSpinner("Running terragrunt run-all plan", p.spinnerOpts)
 	planFile, planJSON, err := p.runPlan(opts, spinner, true)
 	defer func() {
-		err := cleanupPlanFiles(workingDirs, planFile)
+		err := cleanupPlanFiles(projectDirs, planFile)
 		if err != nil {
 			log.Warnf("Error cleaning up plan files: %v", err)
 		}
@@ -210,15 +222,15 @@ func (p *DirProvider) generatePlanJSONs(configDirs []string, workingDirs []strin
 		return [][]byte{planJSON}, nil
 	}
 
-	outs := make([][]byte, 0, len(configDirs))
+	outs := make([][]byte, 0, len(projectDirs))
 	spinnerMsg := "Running terragrunt show"
-	if len(configDirs) > 1 {
+	if len(projectDirs) > 1 {
 		spinnerMsg += " for each project"
 	}
 	spinner = ui.NewSpinner(spinnerMsg, p.spinnerOpts)
 
-	for i, path := range configDirs {
-		opts, err := p.buildCommandOpts(path)
+	for _, projectDir := range projectDirs {
+		opts, err := p.buildCommandOpts(projectDir.ConfigDir)
 		if err != nil {
 			return [][]byte{}, err
 		}
@@ -226,7 +238,7 @@ func (p *DirProvider) generatePlanJSONs(configDirs []string, workingDirs []strin
 			defer os.Remove(opts.TerraformConfigFile)
 		}
 
-		out, err := p.runShow(opts, spinner, filepath.Join(workingDirs[i], planFile))
+		out, err := p.runShow(opts, spinner, filepath.Join(projectDir.WorkingDir, planFile))
 		if err != nil {
 			return outs, err
 		}
@@ -236,13 +248,13 @@ func (p *DirProvider) generatePlanJSONs(configDirs []string, workingDirs []strin
 	return outs, nil
 }
 
-func cleanupPlanFiles(paths []string, planFile string) error {
+func cleanupPlanFiles(projectDirs []terragruntProjectDirs, planFile string) error {
 	if planFile == "" {
 		return nil
 	}
 
-	for _, path := range paths {
-		err := os.Remove(filepath.Join(path, planFile))
+	for _, projectDir := range projectDirs {
+		err := os.Remove(filepath.Join(projectDir.WorkingDir, planFile))
 		if err != nil {
 			return err
 		}
