@@ -52,7 +52,7 @@ func (s *Spinner) Stop() {
 }
 
 func (s *Spinner) Fail() {
-	if !s.spinner.Active() {
+	if s.spinner == nil || !s.spinner.Active() {
 		return
 	}
 	s.Stop()
@@ -67,6 +67,11 @@ func (s *Spinner) Fail() {
 	}
 }
 
+func (s *Spinner) SuccessWithMessage(newMsg string) {
+	s.msg = newMsg
+	s.Success()
+}
+
 func (s *Spinner) Success() {
 	if !s.spinner.Active() {
 		return
